@@ -8,6 +8,8 @@ On linux depends on node and:
     sudo apt-get install pkg-config build-essential zlib1g-dev
 '
 
+git submodule update --init
+
 CURRENT_DIR="$( cd "$( dirname $BASH_SOURCE )" && pwd )"
 
 ARGS="$@"
@@ -63,7 +65,7 @@ if [[ ! `which node` ]]; then
 fi
 
 export LDFLAGS=${LDFLAGS:-""}
-export CXXFLAGS=${CXXFLAGS:-""}
+export CXXFLAGS="${CXXFLAGS:-""} -D_GLIBCXX_USE_CXX11_ABI=0"
 
 if [[ $UNAME == 'Linux' ]]; then
     export LDFLAGS='-Wl,-z,origin -Wl,-rpath=\$$ORIGIN '${LDFLAGS}
@@ -107,5 +109,5 @@ module.exports.env = {
 " > ${MODULE_PATH}/mapnik_settings.js
 
 # cleanup
-rm -rf $BUILD_DIR
+#rm -rf $BUILD_DIR
 set +u +e
