@@ -5,7 +5,7 @@ var assert = require('assert');
 var util = require('util');
 var fs = require('fs');
 var path = require('path');
-var mercator = new(require('sphericalmercator'))();
+var mercator = new(require('@mapbox/sphericalmercator'))();
 var existsSync = require('fs').existsSync || require('path').existsSync;
 var overwrite_expected_data = false;
 
@@ -299,9 +299,9 @@ describe('mapnik.VectorTile.composite', function() {
         var world_clipping_extent = [-20037508.34,-20037508.34,20037508.34,20037508.34];
         vtile.composite([vtile2],{reencode:true});
         vtile1.composite([vtile2],{reencode:true,max_extent:world_clipping_extent});
-        assert.equal(vtile.getData().length,54781);
+        assert.equal(vtile.getData().length,54837);
         assert.deepEqual(vtile.names(),["water","admin"]);
-        assert.equal(vtile1.getData().length,54463);
+        assert.equal(vtile1.getData().length,54576);
         assert.deepEqual(vtile1.names(),["water","admin"]);
         var expected_file = data_base +'/expected/world-reencode.png';
         var expected_file2 = data_base +'/expected/world-reencode-max-extent.png';
@@ -313,14 +313,14 @@ describe('mapnik.VectorTile.composite', function() {
                 assert.equal(0,compare_to_image(im2,expected_file2));
                 vtile3.composite([vtile2],{reencode:true}, function(err) {
                     if (err) throw err;
-                    assert.equal(vtile3.getData().length,54781);
+                    assert.equal(vtile3.getData().length,54837);
                     assert.deepEqual(vtile3.names(),["water","admin"]);
                     vtile3.render(map,new mapnik.Image(256,256),function(err,im) {
                         if (err) throw err;
                         assert.equal(0,compare_to_image(im,expected_file));
                         vtile4.composite([vtile2],{reencode:true,max_extent:world_clipping_extent}, function(err) {
                             if (err) throw err;
-                            assert.equal(vtile4.getData().length,54463);
+                            assert.equal(vtile4.getData().length,54576);
                             assert.deepEqual(vtile4.names(),["water","admin"]);
                             assert.equal(0,compare_to_image(im2,expected_file2));
                             vtile4.render(map,new mapnik.Image(256,256),function(err,im) {
